CREATE TABLE manifests
(
  manifest_id INTEGER PRIMARY KEY NOT NULL,
  version INTEGER DEFAULT 0 NOT NULL,
  as2_api_url TEXT NOT NULL,
  as3_api_url TEXT NOT NULL,
  updated_at INTEGER DEFAULT 0 NOT NULL
);
INSERT INTO manifests VALUES(1, 0, "", "", CURRENT_TIMESTAMP);

CREATE TABLE games
(
  game_id INTEGER NOT NULL,
  author TEXT COLLATE NOCASE NOT NULL,
  permalink TEXT COLLATE NOCASE NOT NULL,
  title TEXT COLLATE NOCASE NOT NULL,
  category TEXT COLLATE NOCASE NOT NULL,
  position INTEGER DEFAULT 100000 NOT NULL,
  rating REAL DEFAULT 0 NOT NULL,

  as3 INTEGER NOT NULL,
  bgcolor TEXT DEFAULT "000000",
  width INTEGER NOT NULL,
  height INTEGER NOT NULL,

  filename TEXT NOT NULL,
  files TEXT NOT NULL,
  total_size INTEGER NOT NULL,
  icon_url TEXT NOT NULL,
  base_url TEXT NOT NULL,
  latest_version INTEGER NOT NULL,
  published_at INTEGER NOT NULL,

  description TEXT DEFAULT "",
  instructions TEXT DEFAULT "",
  news TEXT DEFAULT "",
  downloadable INTEGER DEFAULT 0 NOT NULL,
  fullscreen INTEGER DEFAULT 1 NOT NULL,
  featured INTEGER DEFAULT 0 NOT NULL
);
CREATE UNIQUE INDEX idx_games_on_game_id ON games(game_id);

CREATE TABLE user_game_data
(
  user_game_data_id INTEGER PRIMARY KEY NOT NULL,
  user_id INTEGER NOT NULL,
  game_id INTEGER NOT NULL REFERENCES games(game_id) ON DELETE CASCADE,
  gameplays INTEGER DEFAULT 0 NOT NULL,
  last_played INTEGER DEFAULT 0 NOT NULL,
  rating REAL DEFAULT 0 NOT NULL
);
CREATE UNIQUE INDEX idx_ugd_on_user_id_and_game_id ON user_game_data(user_id,game_id);

CREATE TABLE statistics
(
  statistic_id INTEGER UNIQUE NOT NULL,
  game_id INTEGER NOT NULL REFERENCES games(game_id) ON DELETE CASCADE,
  name TEXT NOT NULL,
  stat_type TEXT COLLATE NOCASE DEFAULT "max" NOT NULL,
  description TEXT NOT NULL,
  display_in_table INTEGER NOT NULL
);
CREATE INDEX idx_statistics_on_game_id ON statistics(game_id);

CREATE TABLE statistic_records
(
  statistic_id INTEGER NOT NULL REFERENCES statistics(statistic_id) ON DELETE CASCADE,
  user_id INTEGER NOT NULL,
  current_value INTEGER NOT NULL,
  accumulated_value INTEGER NOT NULL,
  last_sent_value INTEGER NOT NULL,
  sent_at INTEGER DEFAULT 0 NOT NULL,
  dirty INTEGER DEFAULT 0 NOT NULL
);
CREATE UNIQUE INDEX idx_sr_on_user_id_and_statistic_id ON statistic_records(user_id, statistic_id);

CREATE TABLE installation_records
(
  game_id INTEGER UNIQUE NOT NULL REFERENCES games(game_id) ON DELETE CASCADE,
  install_location TEXT COLLATE NOCASE NOT NULL,
  version INTEGER NOT NULL
);